libatomic_ops: Access hardware-provided atomic memory update operations
=======================================================================

Description
-----------

This package provides semi-portable access to hardware-provided
atomic memory update operations on a number of architectures.


License
-------

- MIT (core library) + GPL 2.0+ (gpl extension library)


Upstream Contact
----------------

https://github.com/ivmai/libatomic_ops/


Special Update/Build Instructions
---------------------------------

None.
